Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1060)

Unified Diff: webrtc/media/base/videoframefactory.h

Issue 2009193002: Delete IsMutable and IsExclusive methods. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Delete redundant RefCountedObject wrapping. Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/media/base/videoframe.cc ('k') | webrtc/media/base/videoframefactory.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/media/base/videoframefactory.h
diff --git a/webrtc/media/base/videoframefactory.h b/webrtc/media/base/videoframefactory.h
index 6aa2ce51733b0c01ea8d5187ace63865a2d32571..985199f646f12d8285547e8eeadefe8b07ed3890 100644
--- a/webrtc/media/base/videoframefactory.h
+++ b/webrtc/media/base/videoframefactory.h
@@ -13,6 +13,7 @@
#include <memory>
+#include "webrtc/common_video/include/i420_buffer_pool.h"
#include "webrtc/media/base/videoframe.h"
namespace cricket {
@@ -52,9 +53,9 @@ class VideoFrameFactory {
bool apply_rotation_;
private:
// An internal frame buffer to avoid reallocations. It is mutable because it
// does not affect behaviour, only performance.
- mutable std::unique_ptr<VideoFrame> output_frame_;
+ mutable webrtc::I420BufferPool pool_;
};
} // namespace cricket
« no previous file with comments | « webrtc/media/base/videoframe.cc ('k') | webrtc/media/base/videoframefactory.cc » ('j') | no next file with comments »
@@ -52,9 +53,9 @@ class VideoFrameFactory {
bool apply_rotation_;
private:
- // An internal frame buffer to avoid reallocations. It is mutable because it
+ // An internal pool to avoid reallocations. It is mutable because it
// does not affect behaviour, only performance.

Powered by Google App Engine
This is Rietveld 408576698